@@ -120,10 +120,12 @@ class DeltaTable:
 
     def __init__(self, schema_name: str,
                  table_name: str,
+                 upload_path: str,
                  column_list: List[DeltaTableColumn] = [],
                  **kw) -> None:
         self.schema_name = schema_name
         self.table_name = table_name
+        self.upload_path = upload_path
         self.columns = self._get_column_list(column_list)
         self.kw = kw
         self.etl_code_stmts = self.create_table_etl_code()
@@ -181,10 +183,6 @@ class DeltaTable:
     def upsert_sql_str(self):
         return self.etl_code_stmts['upsert_sql_str']
 
-    @property
-    def upload_path(self):
-        return f"s3://tpg-ds-db-exports/prd/dbname={self.schema_name}/tablename={self.table_name}/"
-
     @property
     def checkpoint_base_path(self):
         return f"/tmp/delta/{self.schema_name}/{self.table_name}"
